%% Construction of the capital stock series, and the related depreciation rate delta for Italy

close all;
clc; clear;
warning('off', 'all')

dataoriginal = readtable('Investments and Capital Consumption.xlsx');

year    = dataoriginal.year;
yy2019  = find(year==2019);

% normalize series from original units measure in euros
rinv_ita    = dataoriginal.real_fixed_inv_lcu(1:yy2019)/1E12;
rkcons      = dataoriginal.cons_fixed_K_constantLCU(1:yy2019)/1E12;
rgdp        = dataoriginal.gdp_constantLCU(1:yy2019)/1E12;

ninv_ita    = dataoriginal.nominal_fixed_inv_lcu(1:yy2019)/1E12;
nkcons      = dataoriginal.cons_fixed_K_currentLCU(1:yy2019)/1E12;
ngdp        = dataoriginal.gdp_currentLCU(1:yy2019)/1E12;


% write a guess to initiate the problem solution
options     = optimoptions('fsolve', 'FunctionTolerance', 1E-8, 'Display', 'off');

k0guess     = 2;
deltaguess  = 0.1;
ktguess     = linspace(k0guess, 6, length(rinv_ita)-1)';
firstguess  = [ deltaguess; k0guess; ktguess] ; 


% Solve the problem to compute the total depreciation rate
sol       = fsolve(@(x) f_kstock_delta_kt(x, rinv_ita, rgdp, rkcons), firstguess, options);
delta     = sol(1,1)
rkstock    = sol(2:end,1);


plot(year(1:yy2019), rkstock)

% The capital stock series is in line with the overall series provided by ISTAT


%% Solve for the capital stock in each sector in each region


regions = cell({'nor', 'sou'});
sectors = cell({'tot', 'agr', 'mfg', 'serv'});

yy1995 = find(year==1995);

% % Original data in millions of euros, I import them transforming them in billions
for rr = 1:length(regions)
    for ss = 1:length(sectors)
        rinv.(regions{1,rr}).(sectors{1,ss})    = dataoriginal.(['rinv_' regions{1,rr} '_' sectors{1,ss} ])(yy1995:yy2019)/1E3;
        rva.(regions{1,rr}).(sectors{1,ss})     = dataoriginal.(['rva_' regions{1,rr} '_' sectors{1,ss} ])(yy1995:yy2019)/1E3;
    end
end

% now we have a slightly different procedure because we already know
% delta. Therefore, there is one variable less to compute, and we get around
% the need to compute the consumption of fixed capital

k0guess2     = 200;
ktguess2     = linspace(k0guess2, 300, length(rinv.nor.agr)-1)';
firstguess_reg  = [ k0guess2; ktguess2 ] ;

for rr = 1:length(regions)
    for ss = 1:length(sectors)
        kstockreg.(regions{1,rr}).(sectors{1,ss})   = fsolve(@(x) f_kstock_regional(x, rinv, rva, delta, regions, sectors, rr, ss), firstguess_reg, options);
    end
end


