%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% THE DUALITY OF THE ITALIAN ECONOMY 
%--------------------------------------------------------------------------
% MATLAB program to perform the counterfactuals. The program first runs   
% the program "ComputeWedges.m" which computes the wedges and then it 
% compute the counterfactual numbers. For any counterfactual exercise it
% will re-run "ComputeWedges.m".  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all; clc;
close all;

%%
%===============================================================================
%===============================================================================
% Starts counterfactualS
%===============================================================================
%===============================================================================

nCases=2;
nCounterFactuals=6;
TableA=zeros(nCounterFactuals,4);
TableB=zeros(nCounterFactuals,4);
Change_In_Ratio=zeros(nCases,nCounterFactuals);
for nn = 1:nCases
  for jj = 1:nCounterFactuals

  %===============================================================================
  % Run program "ComputeWedges.m"
  %===============================================================================

    run('ComputeWedges.m');

  %===============================================================================
  % Set average wedges
  %===============================================================================

    if nn==1
    %======================================
    % Removing labor wedge difference only
    %======================================
      if jj==2
        Ave_wedge_l_off(2,:)=Ave_wedge_l_off(1,:);
        Ave_wedge_l_unoff(2,:)=Ave_wedge_l_unoff(1,:);
      end

    %=======================================
    % Removing capita wedge difference only
    %=======================================
      if jj==3
        Ave_wedge_k_off(2,:)=Ave_wedge_k_off(1,:);
        Ave_wedge_k_unoff(2,:)=Ave_wedge_k_unoff(1,:);
      end

    %===========================================
    % Removing int productivity difference only
    %============================================
      if jj==4
        Ave_IntProd(2,:)=Ave_IntProd(1,:);
        Ave_wedge_x(2,:)=Ave_wedge_x(1,:);
      end

    %===========================================
    % Removing fin productivity difference only
    %============================================
      if jj==5
        Ave_FinProd(2)=Ave_FinProd(1);
      end

    %========================================
    % Removing inter-regional transfers only
    %=========================================
      if jj==6
        Ave_GovTra(2)=Ave_GovTra(2)*0;
        Ave_GovTra(1) = - Ave_GovTra(2)*PAR.mu(2)/PAR.mu(1);
      end

    else

    %=============================================
    % Same wedges and no inter-regional transfers
    %=============================================
      if jj==1
        Ave_wedge_l_off(2,:)=Ave_wedge_l_off(1,:);
        Ave_wedge_l_unoff(2,:)=Ave_wedge_l_unoff(1,:);
        Ave_wedge_k_off(2,:)=Ave_wedge_k_off(1,:);
        Ave_wedge_k_unoff(2,:)=Ave_wedge_k_unoff(1,:);
        Ave_IntProd(2,:)=Ave_IntProd(1,:);
        Ave_wedge_x(2,:)=Ave_wedge_x(1,:);
        Ave_FinProd(2)=Ave_FinProd(1);
        Ave_GovTra(2)=Ave_GovTra(2)*0;
        Ave_GovTra(1) = - Ave_GovTra(2)*PAR.mu(2)/PAR.mu(1);
      end

    %=======================================
    % Allow for labor wedge difference only
    %=======================================
      if jj==2
        Ave_wedge_k_off(2,:)=Ave_wedge_k_off(1,:);
        Ave_wedge_k_unoff(2,:)=Ave_wedge_k_unoff(1,:);
        Ave_IntProd(2,:)=Ave_IntProd(1,:);
        Ave_wedge_x(2,:)=Ave_wedge_x(1,:);
        Ave_FinProd(2)=Ave_FinProd(1);
        Ave_GovTra(2)=Ave_GovTra(2)*0;
        Ave_GovTra(1) = - Ave_GovTra(2)*PAR.mu(2)/PAR.mu(1);
      end

    %=========================================
    % Allow for capital wedge difference only
    %=========================================
      if jj==3
        Ave_wedge_l_off(2,:)=Ave_wedge_l_off(1,:);
        Ave_wedge_l_unoff(2,:)=Ave_wedge_l_unoff(1,:);
        Ave_IntProd(2,:)=Ave_IntProd(1,:);
        Ave_wedge_x(2,:)=Ave_wedge_x(1,:);
        Ave_FinProd(2)=Ave_FinProd(1);
        Ave_GovTra(2)=Ave_GovTra(2)*0;
        Ave_GovTra(1) = - Ave_GovTra(2)*PAR.mu(2)/PAR.mu(1);
      end

    %============================================
    % Allow for int productivity difference only
    %============================================
      if jj==4
        Ave_wedge_l_off(2,:)=Ave_wedge_l_off(1,:);
        Ave_wedge_l_unoff(2,:)=Ave_wedge_l_unoff(1,:);
        Ave_wedge_k_off(2,:)=Ave_wedge_k_off(1,:);
        Ave_wedge_k_unoff(2,:)=Ave_wedge_k_unoff(1,:);
        Ave_FinProd(2)=Ave_FinProd(1);
        Ave_GovTra(2)=Ave_GovTra(2)*0;
        Ave_GovTra(1) = - Ave_GovTra(2)*PAR.mu(2)/PAR.mu(1);
      end

    %============================================
    % Allow for fin productivity difference only
    %============================================
      if jj==5
        Ave_wedge_l_off(2,:)=Ave_wedge_l_off(1,:);
        Ave_wedge_l_unoff(2,:)=Ave_wedge_l_unoff(1,:);
        Ave_wedge_k_off(2,:)=Ave_wedge_k_off(1,:);
        Ave_wedge_k_unoff(2,:)=Ave_wedge_k_unoff(1,:);
        Ave_IntProd(2,:)=Ave_IntProd(1,:);
        Ave_wedge_x(2,:)=Ave_wedge_x(1,:);      
        Ave_GovTra(2)=Ave_GovTra(2)*0;
        Ave_GovTra(1) = - Ave_GovTra(2)*PAR.mu(2)/PAR.mu(1);
      end

    %=========================================
    % Allow for inter-regional transfers only
    %=========================================
      if jj==6
        Ave_wedge_l_off(2,:)=Ave_wedge_l_off(1,:);
        Ave_wedge_l_unoff(2,:)=Ave_wedge_l_unoff(1,:);
        Ave_wedge_k_off(2,:)=Ave_wedge_k_off(1,:);
        Ave_wedge_k_unoff(2,:)=Ave_wedge_k_unoff(1,:);
        Ave_IntProd(2,:)=Ave_IntProd(1,:);
        Ave_wedge_x(2,:)=Ave_wedge_x(1,:);
        Ave_FinProd(2)=Ave_FinProd(1);
      end
    end  
    
    %% Set constant parameter for taux and taub and take the mean of wedge_b
    taux_const_mx=zeros(length(area),length(sec));
    taub_const_vec=zeros(length(area),1);
    AAve_wedge_b=mean(Ave_wedge_b);
    for aa = 1:length(area)
      for ss = 1:length(sec)
        share_unoff=Xtilde.(area{1,aa}).(sec{1,ss})./(X.(area{1,aa}).(sec{1,ss})+Xtilde.(area{1,aa}).(sec{1,ss}));        
        taux_const_mx(aa,ss)=Ave_wedge_x(aa,ss)-PAR.taux_slope*mean(share_unoff,'omitnan'); 
      end
      debt=0;
      taub_const_vec(aa)=AAve_wedge_b-PAR.taub_slope*PAR.mu(aa)*debt; 
      Ave_wedge_b(aa)=AAve_wedge_b;
    end  
    PAR.taux_const=taux_const_mx;
    PAR.taub_const=taub_const_vec;


    %% Set constants in the South equal to the North 
    %if (nn==1) && (jj==4)
    %PAR.taux_const(2,:)=PAR.taux_const(1,:);
    %end

    %%
    %=========================================================================
    %=========================================================================
    % SOLVE FOR THE STEADY STATE
    %=========================================================================
    %=========================================================================

    f = @(xVar)FindSS(xVar,PAR,area,sec,Ave_wedge_l_off,Ave_wedge_l_unoff,Ave_wedge_k_off,Ave_wedge_k_unoff, ...
                     Ave_wedge_x,Ave_wedge_b,Ave_IntProd,Ave_FinProd,Ave_GovPur,Ave_GovTra);

    load("xVar.mat");
    x0=xVar;

    xVar = fsolve(f,x0);
    fx=f(xVar);

    %% Rearrange solution variables
    LL=reshape(xVar(1:4),2,2)';
    LLtilde=reshape(xVar(5:8),2,2)';
    KK=reshape(xVar(9:12),2,2)';
    KKtilde=reshape(xVar(13:16),2,2)';
    XX=reshape(xVar(17:20),2,2)';
    XXtilde=reshape(xVar(21:24),2,2)';
    PP=reshape(xVar(25:28),2,2)';
    MM=reshape(xVar(29:32),2,2)';
    CC=xVar(33:34);
    BB=xVar(35:36);
    QQ=xVar(37:38);

    ssY(1)=XX(1,1)+XXtilde(1,1)+(XX(1,2)+XXtilde(1,2))*PP(1,2)/PP(1,1);
    ssY(2)=XX(2,1)+XXtilde(2,1)+(XX(2,2)+XXtilde(2,2))*PP(2,2)/PP(2,1);

    if jj==1
      Base_Ratio=ssY(2)/ssY(1);
    end  

    if (nn==1)
      TableA(jj,1)=ssY(1);
      TableA(jj,2)=ssY(2);
      TableA(jj,3)=ssY(2)/ssY(1);
      TableA(jj,4)=ssY(2)/ssY(1)-Base_Ratio;
    else
      TableB(jj,1)=ssY(1);
      TableB(jj,2)=ssY(2);
      TableB(jj,3)=ssY(2)/ssY(1);
      TableB(jj,4)=ssY(2)/ssY(1)-Base_Ratio;
    end  

    Change_In_Ratio(nn,jj)=ssY(2)/ssY(1)-Base_Ratio;

    formatSpec='%7.3f';
    a1= ['GDP North       = ', num2str(ssY(1),formatSpec)];
    a2= ['GDP South       = ', num2str(ssY(2),formatSpec)];
    a12=['GDP ratio       = ', num2str(ssY(2)/ssY(1),formatSpec)];
    a13=['GDP gap         = ', num2str(1-ssY(2)/ssY(1),formatSpec)];
    a14=['Change in ratio = ', num2str(ssY(2)/ssY(1)-Base_Ratio,formatSpec)];


    if nn==1
      ss1=[' REMOVING DIFFERENCE IN '];
    else
      ss1=[' ALLOWING DIFFERENCE IN '];
    end  
    if jj==1
      ss2=['NO WEDGES'];
    end  
    if jj==2
      ss2=['LABOR WEDGES'];
    end  
    if jj==3
      ss2=['CAPITAL WEDGES'];
    end  
    if jj==4
      ss2=['INT PRODUCTIVITY'];
    end  
    if jj==5
      ss2=['FINAL PRODUCTIVITY'];
    end  
    if jj==6
      ss2=['INTER_REGIONAL TRANSFERS'];
    end  

    ss=[ss1,ss2];

    disp('====================================================');
    disp(ss);
    disp('====================================================');
    disp(a1);
    disp(a2);
    disp(a12);
    disp(a13);
    disp(a14);
    disp('====================================================');

%INTER-REGIONAL TRANSFERS
%disp(Ave_GovTra(1)/ssY(1));
%disp(Ave_GovTra(2)/ssY(2));


%pause;

  end
end  


formatSpec='%10.3f';
tab1A=num2str(TableA,formatSpec);
tab1B=num2str(TableB,formatSpec);
disp('  ');
disp('====================================================');
disp(' TABLE 1 - Part A');
disp('====================================================');
disp(tab1A);
disp('====================================================');
disp(' TABLE 1 - Part B');
disp('====================================================');
disp(tab1B);


Ave_Change_In_Ratio=(TableA(:,4)-TableB(:,4))*100/2;
Ave_Change_In_Ratio=Ave_Change_In_Ratio(2:nCounterFactuals);
Sum_Change_In_Ratio=sum(Ave_Change_In_Ratio);

formatSpec=' %7.1f%%';
aa1=num2str(Ave_Change_In_Ratio',formatSpec);
aa2=num2str(Sum_Change_In_Ratio,formatSpec);
disp('====================================================');
disp(' TABLE 2');
disp('====================================================');
disp([aa1,'  ||  ',aa2]);
disp('====================================================');
