%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% THE DUALITY OF THE ITALIAN ECONOMY 
%--------------------------------------------------------------------------
% MATLAB program to construct the graphs for the wedge. The program first   
% runs the program "ComputeWedges.m" which computes the wedges and then it 
% constructs the graphs. 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all; clc;
close all;

%%
%===============================================================================
% Run program "ComputeWedges.m"
%===============================================================================

run('ComputeWedges.m');

%===============================================================================
% Plot Wedge for labor 
%===============================================================================

% Official sector

figure;
for ss = 1:length(sec)
  subplot(2, 2, ss)
  for aa = 1:length(area)
    hold on
    if aa==1
      l = plot(year, wedge_l_off.(area{1,aa}).(sec{1,ss}),'-', 'Color', 'blue', LineWidth = 1.5);
    else
      l = plot(year, wedge_l_off.(area{1,aa}).(sec{1,ss}),'--', 'Color', 'red', LineWidth = 1.5);
    end
  end
  if ss==1 
    title("Tradable sector (official)", Interpreter="latex")
  else
    title("Nontradable sector (official)", Interpreter="latex")
  end
  xlabel("Year", Interpreter="latex")
  ylabel("Labor wedge", Interpreter="latex")
  legend("off")
  ylim([0.0 1.6])
end

% Unofficial sector

for ss = 1:length(sec)
  subplot(2, 2, 2+ss)
  for aa = 1:length(area)
    hold on
    if aa==1
      l = plot(year, wedge_l_unoff.(area{1,aa}).(sec{1,ss}),'-', 'Color', 'blue', LineWidth = 1.5);
    else
      l = plot(year, wedge_l_unoff.(area{1,aa}).(sec{1,ss}),'--', 'Color', 'red', LineWidth = 1.5);
    end
  end
  if ss==1 
    title("Tradable sector (unofficial)", Interpreter="latex")
  else
    title("Nontradable sector (unofficial)", Interpreter="latex")
  end
  xlabel("Year", Interpreter="latex")
  ylabel("Labor wedge", Interpreter="latex")
  if (ss==2)
    legend("North", "South", "interpreter", "latex", "Location", "southeast", numcolumns=1)
  end  
  ylim([0.0 1.6])
end

% Save figure for labor wedge

saveas(l, ['Figures/fig_LaborWedge.png'] )


%===============================================================================
% Plot bond wedge 
%===============================================================================

figure;
for aa = 1:length(area)
  hold on
  if aa==1
    b = plot(year, wedge_b.(area{1,aa}),'-', 'Color', 'blue', LineWidth = 1.5);
  else
    b = plot(year, wedge_b.(area{1,aa}),'--', 'Color', 'red', LineWidth = 1.5);
  end    
end
legend("North", "South", "interpreter", "latex", "Location", "southeast", numcolumns=1)
xlabel("Year", Interpreter="latex")
ylabel("Bond wedge", Interpreter="latex")
title("Wedge for bond market $\tau_{b}$", Interpreter="latex")
ylim([-0.1 0.1]);

% Save figure for bond wedge

saveas(b, ['Figures/fig_BondWedge.png'] )


%===============================================================================
% Plot Wedge for capital 
%===============================================================================

% Official sector

figure;
for ss = 1:length(sec)
  subplot(2, 2, ss)
  for aa = 1:length(area)
    hold on
    if aa==1
      k = plot(year, wedge_k_off.(area{1,aa}).(sec{1,ss}),'-', 'Color', 'blue', LineWidth = 1.5);
    else
      k = plot(year, wedge_k_off.(area{1,aa}).(sec{1,ss}),'--', 'Color', 'red', LineWidth = 1.5);
    end
  end
  if ss==1 
    title("Tradable sector (official)", Interpreter="latex")
  else
    title("Nontradable sector (official)", Interpreter="latex")
  end
  xlabel("Year", Interpreter="latex")
  ylabel("capital wedge", Interpreter="latex")
  legend("off")
  ylim([-0.5 2.0])
end

% Unofficial sector

for ss = 1:length(sec)
  subplot(2, 2, ss+2)
  for aa = 1:length(area)
    hold on
    if aa==1
      k = plot(year, wedge_k_unoff.(area{1,aa}).(sec{1,ss}),'-', 'Color', 'blue', LineWidth = 1.5);
    else
      k = plot(year, wedge_k_unoff.(area{1,aa}).(sec{1,ss}),'--', 'Color', 'red', LineWidth = 1.5);
    end
  end
  if ss==1 
    title("Tradable sector (unofficial)", Interpreter="latex")
  else
    title("Nontradable sector (unofficial)", Interpreter="latex")
  end
  xlabel("Year", Interpreter="latex")
  ylabel("capital wedge", Interpreter="latex")
  if (ss==2)
    legend("North", "South", "interpreter", "latex", "Location", "northeast", numcolumns=1)
  end  
  ylim([-0.5 2.0])
end

% Save figure for Capital wedge

saveas(k,['Figures/fig_CapitalWedge.png'])


%===============================================================================
% Productivity intermediate sector 
%===============================================================================

% Normalize productivity

for ss = 1:length(sec)
  NormFactor(ss)=IntProd_off.("nor").(sec{1,ss})(1);
end
for aa = 1:length(area)
  for ss = 1:length(sec)
    IntProd_off_norm.(area{1,aa}).(sec{1,ss}) = IntProd_off.(area{1,aa}).(sec{1,ss})./NormFactor(ss); 
    IntProd_unoff_norm.(area{1,aa}).(sec{1,ss}) = IntProd_unoff.(area{1,aa}).(sec{1,ss})./NormFactor(ss); 
  end
end

% Plot official sector

figure;
for ss = 1:length(sec)
  subplot(2, 2, ss)
  for aa = 1:length(area)
    hold on
    if aa==1
      y = plot(year, IntProd_off_norm.(area{1,aa}).(sec{1,ss}),'-', 'Color', 'blue', LineWidth = 1.5);
    else
      y = plot(year, IntProd_off_norm.(area{1,aa}).(sec{1,ss}),'--', 'Color', 'red', LineWidth = 1.5);
    end
  end
  if ss==1 
    title("Tradable sector (official)", Interpreter="latex")
  else
    title("Nontradable sector (official)", Interpreter="latex")
  end
  xlabel("Year", Interpreter="latex")
  ylabel("Productivity", Interpreter="latex")
  legend("off")
  ylim([0.7 1.2])
end

% Plot unofficial sector

for ss = 1:length(sec)
  subplot(2, 2, 2+ss)
  for aa = 1:length(area)
    hold on
    if aa==1
      y = plot(year, IntProd_unoff_norm.(area{1,aa}).(sec{1,ss}),'-', 'Color', 'blue', LineWidth = 1.5);
    else
      y = plot(year, IntProd_unoff_norm.(area{1,aa}).(sec{1,ss}),'--', 'Color', 'red', LineWidth = 1.5);
    end
  end   
  if ss==1 
    title("Tradable sector (unofficial)", Interpreter="latex")
  else
    title("Nontradable sector (unofficial)", Interpreter="latex")
  end
  xlabel("Year", Interpreter="latex")
  ylabel("Productivity", Interpreter="latex")
  if (ss==2)
    legend("North", "South", "interpreter", "latex", "Location", "northeast", numcolumns=1)
  end  
  ylim([0.7 1.2])
end

% Save figure for labor wedge

saveas(y, ['Figures/fig_IntProd.png'] )


%===============================================================================
% Productivity final sector 
%===============================================================================

% Normalize productivity

NormFactor=FinProd.("nor")(1);
for aa = 1:length(area)
    FinProd_norm.(area{1,aa}) = FinProd.(area{1,aa})./NormFactor; 
end

figure;
for aa = 1:length(area)
  hold on
  if aa==1
    y = plot(year, FinProd_norm.(area{1,aa}),'-', 'Color', 'blue', LineWidth = 3);
  else
    y = plot(year, FinProd_norm.(area{1,aa}),'--', 'Color', 'red', LineWidth = 3);
  end    
end
legend("North", "South", Interpreter="latex", FontSize=15, Location="southeast", numcolumns=1)
ylim([0.7 1.2])
yticks(0.7:0.1:1.2)

ax = gca;
ax.FontSize = 12;

xlabel("Year", Interpreter="latex",FontSize=14)
ylabel("Productivity", Interpreter="latex",FontSize=14)

% Save figure for labor wedge

saveas(y, ['Figures/fig_FinProd.png'] )
